@@ -1,12 +1,15 @@
+# -*- coding: utf-8 -*-
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'Company',
+    'name_bg_BG': 'Фирма',
     'name_de_DE': 'Unternehmen',
     'name_es_CO': 'Compañía',
     'name_es_ES': 'Empresa',
     'name_fr_FR': 'Société',
-    'version': '1.8.0',
+    'name_nl_NL': 'Bedrijf',
+    'version': '2.0.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -16,6 +19,13 @@ Add company on properties.
 Define new report parser for report with company header.
 Add letter template on party.
 Make the scheduler run on each companies.
+''',
+    'description_bg_BG': ''' - Задаване на фирма и служители
+ - Добавяне на основна и текуща фирма според предпочитания на потребителите
+ - Добавяне на фирма при предпочитания
+ - Задаване на нов анализатор на справки с фирмен горен колонтитул
+ - Добавяне на шаблон на писмо за партньор
+ - Възможност планировщика да работи на всяка фирма
 ''',
     'description_de_DE': ''' - Ermöglicht die Eingabe von Umternehmen und Mitarbeitern.
  - Fügt Haupt- und aktuelles Unternehmen zu den Benutzereinstellungen hinzu.
@@ -44,6 +54,20 @@ Ajoute la société sur les propriétés.
 Défini un nouveau moteur de rapport gérant une entête par société.
 Ajoute un canva de lettre par tiers.
 Lance les planificateurs sur chaque société.
+''',
+    'description_nl_NL': ''' - Definieert bedrijf en werknemers.
+ - Voegt moederbedrijf en huidig bedrijf toe aan gebruikers voorkeuren.
+ - Voegt bedrijf toe aan eigenschappen.
+ - Definieert nieuwe rapport routine voor een rapport met 'bedrijfskop'.
+ - Voegt briefsjabloon toe aan relatie.
+ - Initieert automatisch herhalende taken voor elk bedrijf.
+''',
+    'description_ru_RU': '''Учет организаций и сотрудников.
+ - Добавление основной и дочерних организаций
+ - Добавление учетных организаций и свойств
+ - Настройка отчетов для печати на фирменных бланках.
+ - Добавление шаблона письма.
+ - Устанавливает планировщика на работу с каждой учетной организацией.
 ''',
     'depends': [
         'ir',
@@ -56,9 +80,12 @@ Lance les planificateurs sur chaque société.
         'cron.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
         'fr_FR.csv',
+        'nl_NL.csv',
+        'ru_RU.csv',
     ]
 }
